From 5c30695d66365c93ffd292cc50d1f6ea8ef5df5e Mon Sep 17 00:00:00 2001
From: Ahmad <69138416+Ahmad495@users.noreply.github.com>
Date: Thu, 23 May 2024 12:22:41 +0500
Subject: [PATCH] Fixed Typos
---
web/pgadmin/authenticate/mfa/views.py | 10 +++++-----
web/pgadmin/browser/server_groups/servers/__init__.py | 2 +-
.../databases/schemas/packages/edbfuncs/__init__.py | 4 ++--
.../databases/schemas/packages/static/js/package.js | 2 +-
.../databases/schemas/tables/columns/__init__.py | 2 +-
.../servers/databases/static/js/database.js | 2 +-
.../browser/server_groups/servers/roles/__init__.py | 2 +-
.../server_groups/servers/roles/static/js/role.js | 2 +-
.../server_groups/servers/tablespaces/__init__.py | 2 +-
.../servers/tablespaces/static/js/tablespace.js | 2 +-
web/pgadmin/browser/server_groups/servers/types.py | 2 +-
web/pgadmin/misc/cloud/static/js/aws_schema.ui.js | 2 +-
web/pgadmin/misc/cloud/static/js/biganimal.js | 2 +-
.../static/js/components/DebuggerArgumentComponent.jsx | 2 +-
web/pgadmin/tools/schema_diff/model.py | 2 +-
.../tools/schema_diff/static/js/components/Results.jsx | 2 +-
.../static/js/components/sections/MainToolBar.jsx | 2 +-
web/pgadmin/tools/sqleditor/utils/save_changed_data.py | 2 +-
18 files changed, 23 insertions(+), 23 deletions(-)
diff --git a/web/pgadmin/browser/server_groups/servers/__init__.py b/web/pgadmin/browser/server_groups/servers/__init__.py
index e1903499d..aa4cbe6d9 100644
--- a/web/pgadmin/browser/server_groups/servers/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/__init__.py
@@ -1479,7 +1479,7 @@ class ServerNode(PGChildNodeView):
If Yes, connect the server and return connection.
If No, Raise HTTP error and ask for the password.
- In case of 'Save Password' request from user, excrypted Pasword
+ In case of 'Save Password' request from user, excrypted Password
will be stored in the respected server database and
establish the connection OR just connect the server and do not
store the password.
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/packages/edbfuncs/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/packages/edbfuncs/__init__.py
index c4bdc47a4..7c88a401c 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/packages/edbfuncs/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/packages/edbfuncs/__init__.py
@@ -97,7 +97,7 @@ class EdbFuncModule(CollectionNodeModule):
"""
Register preferences for this module.
"""
- # Add the node informaton for browser, not in respective
+ # Add the node information for browser, not in respective
# node preferences
self.browser_preference = Preferences.module('browser')
self.pref_show_system_objects = self.browser_preference.preference(
@@ -665,7 +665,7 @@ class EdbProcModule(CollectionNodeModule):
"""
Register preferences for this module.
"""
- # Add the node informaton for browser, not in respective
+ # Add the node information for browser, not in respective
# node preferences
self.browser_preference = Preferences.module('browser')
self.pref_show_system_objects = self.browser_preference.preference(
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/packages/static/js/package.js b/web/pgadmin/browser/server_groups/servers/databases/schemas/packages/static/js/package.js
index 948e053be..5423a9602 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/packages/static/js/package.js
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/packages/static/js/package.js
@@ -42,7 +42,7 @@ define('pgadmin.node.package', [
hasSQL: true,
hasDepends: true,
Init: function() {
- /* Avoid mulitple registration of menus */
+ /* Avoid multiple registration of menus */
if (this.initialized)
return;
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/columns/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/columns/__init__.py
index 209955af9..5a33dda69 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/columns/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/tables/columns/__init__.py
@@ -618,7 +618,7 @@ class ColumnsView(PGChildNodeView, DataTypeReader):
"""
Convert acl coming from client to required db parsing format.
:param data: Data.
- :param old_data: old data for comparision and get name.
+ :param old_data: old data for Comparison and get name.
"""
# If name is not present in data then
# we will fetch it from old data, we also need schema & table name
diff --git a/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js b/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js
index fbc1387cc..d4c1ce592 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js
+++ b/web/pgadmin/browser/server_groups/servers/databases/static/js/database.js
@@ -66,7 +66,7 @@ define('pgadmin.node.database', [
},
width: '700px',
Init: function() {
- /* Avoid mulitple registration of menus */
+ /* Avoid multiple registration of menus */
if (this.initialized)
return;
diff --git a/web/pgadmin/browser/server_groups/servers/roles/__init__.py b/web/pgadmin/browser/server_groups/servers/roles/__init__.py
index 5bee223fa..98554b33e 100644
--- a/web/pgadmin/browser/server_groups/servers/roles/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/roles/__init__.py
@@ -638,7 +638,7 @@ rolmembership:{
def check_precondition(action=None):
"""
This function will behave as a decorator which will checks the status
- of the database connection for the maintainance database of the server,
+ of the database connection for the maintenance database of the server,
beforeexecuting rest of the operation for the wrapped function. It will
also attach manager, conn (maintenance connection for the server) as
properties of the instance.
diff --git a/web/pgadmin/browser/server_groups/servers/roles/static/js/role.js b/web/pgadmin/browser/server_groups/servers/roles/static/js/role.js
index a06f5ba4c..20e71b24a 100644
--- a/web/pgadmin/browser/server_groups/servers/roles/static/js/role.js
+++ b/web/pgadmin/browser/server_groups/servers/roles/static/js/role.js
@@ -78,7 +78,7 @@ define('pgadmin.node.role', [
return gettext('Group Role') + ' - ' + d.label;
},
Init: function() {
- /* Avoid mulitple registration of menus */
+ /* Avoid multiple registration of menus */
if (this.initialized)
return;
diff --git a/web/pgadmin/browser/server_groups/servers/tablespaces/__init__.py b/web/pgadmin/browser/server_groups/servers/tablespaces/__init__.py
index 704bdaefa..1849d72d1 100644
--- a/web/pgadmin/browser/server_groups/servers/tablespaces/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/tablespaces/__init__.py
@@ -516,7 +516,7 @@ class TablespaceView(PGChildNodeView):
def get_sql(self, gid, sid, data, tsid=None):
"""
- This function will genrate sql from model/properties data
+ This function will generate sql from model/properties data
"""
required_args = [
'name'
diff --git a/web/pgadmin/browser/server_groups/servers/tablespaces/static/js/tablespace.js b/web/pgadmin/browser/server_groups/servers/tablespaces/static/js/tablespace.js
index e1a0d8c9e..dfefc6c81 100644
--- a/web/pgadmin/browser/server_groups/servers/tablespaces/static/js/tablespace.js
+++ b/web/pgadmin/browser/server_groups/servers/tablespaces/static/js/tablespace.js
@@ -47,7 +47,7 @@ define('pgadmin.node.tablespace', [
hasStatistics: true,
statsPrettifyFields: [gettext('Size')],
Init: function() {
- /* Avoid mulitple registration of menus */
+ /* Avoid multiple registration of menus */
if (this.initialized)
return;
diff --git a/web/pgadmin/browser/server_groups/servers/types.py b/web/pgadmin/browser/server_groups/servers/types.py
index 494e9dc75..6d4c26545 100644
--- a/web/pgadmin/browser/server_groups/servers/types.py
+++ b/web/pgadmin/browser/server_groups/servers/types.py
@@ -25,7 +25,7 @@ class ServerType():
Create an instance of this class to define new type of the server support,
In order to define new type of instance, you may want to override this
- class with overriden function - instanceOf for type checking for
+ class with overridden function - instanceOf for type checking for
identification based on the version.
"""
registry = dict()
diff --git a/web/pgadmin/misc/cloud/static/js/aws_schema.ui.js b/web/pgadmin/misc/cloud/static/js/aws_schema.ui.js
index 3a5963062..b31cf040c 100644
--- a/web/pgadmin/misc/cloud/static/js/aws_schema.ui.js
+++ b/web/pgadmin/misc/cloud/static/js/aws_schema.ui.js
@@ -139,7 +139,7 @@ class DatabaseSchema extends BaseUISchema {
}
if (data.db_confirm_password.includes('\'') || data.db_confirm_password.includes('"') ||
data.db_confirm_password.includes('@') || data.db_confirm_password.includes('/')) {
- setErrMsg('db_confirm_password', gettext('Invalid passowrd.'));
+ setErrMsg('db_confirm_password', gettext('Invalid password.'));
return true;
}
diff --git a/web/pgadmin/misc/cloud/static/js/biganimal.js b/web/pgadmin/misc/cloud/static/js/biganimal.js
index 96c36fe41..3f911083c 100644
--- a/web/pgadmin/misc/cloud/static/js/biganimal.js
+++ b/web/pgadmin/misc/cloud/static/js/biganimal.js
@@ -246,7 +246,7 @@ export function getBigAnimalSummary(cloud, bigAnimalClusterTypeData, bigAnimalIn
];
if(bigAnimalClusterTypeData.provider.includes('aws')){
rows4.push(createData(gettext('Volume IOPS'), bigAnimalInstanceData.volume_IOPS));
- rows4.push(createData(gettext('Disk Throuhgput'), bigAnimalInstanceData.disk_throughput));
+ rows4.push(createData(gettext('Disk Throughput'), bigAnimalInstanceData.disk_throughput));
}
const rows5 = [
diff --git a/web/pgadmin/tools/debugger/static/js/components/DebuggerArgumentComponent.jsx b/web/pgadmin/tools/debugger/static/js/components/DebuggerArgumentComponent.jsx
index d75806a1d..1e4518d66 100644
--- a/web/pgadmin/tools/debugger/static/js/components/DebuggerArgumentComponent.jsx
+++ b/web/pgadmin/tools/debugger/static/js/components/DebuggerArgumentComponent.jsx
@@ -736,7 +736,7 @@ export default function DebuggerArgumentComponent({ debuggerInfo, restartDebug,
.catch((error) => {
setLoaderText('');
pgAdmin.Browser.notifier.alert(
- gettext('Error occured: '),
+ gettext('Error occurred: '),
parseApiError(error)
);
});
diff --git a/web/pgadmin/tools/schema_diff/model.py b/web/pgadmin/tools/schema_diff/model.py
index 60accde39..e2c9256af 100644
--- a/web/pgadmin/tools/schema_diff/model.py
+++ b/web/pgadmin/tools/schema_diff/model.py
@@ -32,7 +32,7 @@ class SchemaDiffModel:
def set_result(self, node_name, compare_result):
"""
- This method set the result of the comparision based on nodes.
+ This method set the result of the Comparison based on nodes.
"""
self._comparison_result[node_name] = compare_result
diff --git a/web/pgadmin/tools/schema_diff/static/js/components/Results.jsx b/web/pgadmin/tools/schema_diff/static/js/components/Results.jsx
index 571fc0d25..b231c7171 100644
--- a/web/pgadmin/tools/schema_diff/static/js/components/Results.jsx
+++ b/web/pgadmin/tools/schema_diff/static/js/components/Results.jsx
@@ -76,7 +76,7 @@ export function Results() {
return (
<>
- {gettext('DDL Comparision')}
+ {gettext('DDL Comparison')}
{gettext('Source')}
diff --git a/web/pgadmin/tools/sqleditor/static/js/components/sections/MainToolBar.jsx b/web/pgadmin/tools/sqleditor/static/js/components/sections/MainToolBar.jsx
index da79f4702..b66143877 100644
--- a/web/pgadmin/tools/sqleditor/static/js/components/sections/MainToolBar.jsx
+++ b/web/pgadmin/tools/sqleditor/static/js/components/sections/MainToolBar.jsx
@@ -242,7 +242,7 @@ export function MainToolBar({containerRef, onFilterClick, onManageMacros}) {
queryToolCtx.modal.showModal(gettext('Commit transaction?'), (closeModal)=>(
{
onExecutionDone();
diff --git a/web/pgadmin/tools/sqleditor/utils/save_changed_data.py b/web/pgadmin/tools/sqleditor/utils/save_changed_data.py
index 7384b285a..a72dc2e22 100644
--- a/web/pgadmin/tools/sqleditor/utils/save_changed_data.py
+++ b/web/pgadmin/tools/sqleditor/utils/save_changed_data.py
@@ -28,7 +28,7 @@ def save_changed_data(changed_data, columns_info, conn, command_obj,
conn: The connection object
columns_info: session_obj['columns_info']
client_primary_key: session_obj['client_primary_key']
- auto_commit: If the changes should be commited automatically.
+ auto_commit: If the changes should be committed automatically.
"""
status = False
res = None
diff --git a/web/pgadmin/authenticate/mfa/views.py b/web/pgadmin/authenticate/mfa/views.py
index 843b8dec7..abf5eac55 100644
--- a/web/pgadmin/authenticate/mfa/views.py
+++ b/web/pgadmin/authenticate/mfa/views.py
@@ -37,8 +37,8 @@ def __handle_mfa_validation_request(
mfa_method: str, user_mfa_auths: dict, form_data: dict
) -> None:
"""
- An internal utlity function to execute mfa.validate(...) method in case, it
- matched the following conditions:
+ An internal utility function to execute mfa.validate(...) method in case,
+ it matched the following conditions:
1. Method specified is a valid and in the supported methods list.
2. User has registered for this auth method.
@@ -172,7 +172,7 @@ def _mfa_registration_view(
if form_data[mfa.name] == 'SETUP':
if supported_mfa['registered'] is True:
- flash(_("'{}' is already registerd'").format(mfa.label),
+ flash(_("'{}' is already registered'").format(mfa.label),
MessageType.SUCCESS)
return None
@@ -238,7 +238,7 @@ def __handle_registration_view_for_post_method(
_next_url (str) : Redirect to which url, when clicked on the
'continue' button on the registration page.
_mfa_auths (dict): A dict object returned by the method -
- 'mfa_suppored_methods'.
+ 'mfa_supported_methods'.
Returns:
(Union[str, None], Union[Response, None], Union[dict, None]):
@@ -289,7 +289,7 @@ def registration_view() -> Response:
A url end-point to register/deregister an authentication method.
It supports two HTTP methods:
* GET : Generate a view listing all the suppoted list with 'Setup',
or 'Delete' buttons. If user has registered for the auth method, it
will render a 'Delete' button next to it, and 'Setup' button
otherwise.
@@ -289,7 +289,7 @@ def registration_view() -> Response:
A url end-point to register/deregister an authentication method.
It supports two HTTP methods:
- * GET : Generate a view listing all the suppoted list with 'Setup',
+ * GET : Generate a view listing all the supported list with 'Setup',
or 'Delete' buttons. If user has registered for the auth method, it
will render a 'Delete' button next to it, and 'Setup' button